"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createGraphQLSchemaPlugin = void 0;
var _baseSchema = require("./baseSchema");
var _api = require("@webiny/api");
var _createFieldTypePluginRecords = require("@webiny/api-headless-cms/graphql/schema/createFieldTypePluginRecords");
var _filesSchema = require("./filesSchema");
var _isInstallationPending = require("../cmsFileStorage/isInstallationPending");
const createGraphQLSchemaPlugin = () => {
  return [(0, _baseSchema.createBaseSchema)(),
  // Files schema is generated dynamically, based on a CMS model, so we need to
  // register it from a ContextPlugin, to perform additional bootstrap.
  new _api.ContextPlugin(async context => {
    if ((0, _isInstallationPending.isInstallationPending)(context)) {
      return;
    }
    await context.security.withoutAuthorization(async () => {
      const fileModel = await context.cms.getModel("fmFile");
      const models = await context.cms.listModels();
      const fieldPlugins = (0, _createFieldTypePluginRecords.createFieldTypePluginRecords)(context.plugins);
      const graphQlPlugin = (0, _filesSchema.createFilesSchema)({
        model: fileModel,
        models,
        plugins: fieldPlugins
      });
      context.plugins.register(graphQlPlugin);
    });
  })];
};
exports.createGraphQLSchemaPlugin = createGraphQLSchemaPlugin;